<?php

namespace App\Http\Controllers;

use Log;
use Validator;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Model\PharmaviteModel;
use App\Http\ResponseHelper;

class PharmaviteController extends Controller
{
    private $responseHelper;
    private $pharmaviteObj;

    public function __construct()
    {
        $this->responseHelper = new ResponseHelper();
        $this->pharmaviteObj = new PharmaviteModel();
    }

    /**
     * phvContactus post request
     */
    public function phvContactus(Request $request) {

        $requestData = $request->input('data');
        if (empty($requestData)) {

            $returnData = [
                'error' => 'Invalid endpoint request'
            ];
            $message = 'Failed';
            Log::error($returnData);
            if (!empty($request->input('callback'))) {
                return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
            } else {
                return $this->responseHelper->returnData(null, '600', $message, $returnData );
            }
        }
        $receivedData = json_decode($requestData);
        $requestKeys = ['EMail','FirstName','LastName','MessageBody'];
        $optionalkeys = ['Subject'];
        $keysInTheRequest = [];
        $emptyValueKeys = [];
        foreach ($receivedData as $key => $recValue) {

            $keysInTheRequest[] = $key;
            if (empty($recValue) && !in_array($key, $optionalkeys)) {

                $emptyValueKeys[] = $key;
            }
        }
        $keyComparedStatus = array_diff($requestKeys, $keysInTheRequest);
        if(!empty($keyComparedStatus)) {

            $missedParameters = implode(",",$keyComparedStatus);
            $message = 'Failed';
            $returnData = [
                'error' => $missedParameters.' endpoint parameters are missing in the request'
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        if (!empty($emptyValueKeys)) {

            $emptyValueKeys = implode(",",$emptyValueKeys);
            $message = 'Failed';
            $returnData = [
                'error' => $emptyValueKeys.' endpoint parameter values are empty in the request'
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        $postPath = env('POST_PHVCONTACT_URL',true);
        $response = $this->pharmaviteObj->postRequestData($postPath, $requestData);
        if (strtolower(trim($response)) != 'success') {

            $message = 'Failed';
            $returnData = [
                'error' => 'Error occured while posting the request to the API',
                'request' => $requestData
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        $message = 'Success';
        $returnData = [
            'message' => 'Successfully posted the given request in the API (Email: '.$receivedData->EMail.')'
        ];
        Log::info($returnData);
        return $this->responseHelper->returnData($request->input('callback'), '200', $message, $returnData );
    } 

    /**
     * nmmbg post request
     */
    public function nmmbg(Request $request) {

        $requestData = $request->input('data');
        if (empty($requestData)) {

            $returnData = [
                'error' => 'Invalid endpoint request'
            ];
            $message = 'Failed';
            Log::error($returnData);
            if (!empty($request->input('callback'))) {
                return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
            } else {
                return $this->responseHelper->returnData(null, '600', $message, $returnData );
            }
        }
        $receivedData = json_decode($requestData);
        $requestKeys = ['EMail','FirstName','LastName','AddressLine1','City','State','Zip','ReturnProductId','ProductListNumber'];
        $keysInTheRequest = [];
        $emptyValueKeys = [];
        foreach ($receivedData as $key => $recValue) {

            $keysInTheRequest[] = $key;
            if (empty($recValue) && $key !='AddressLine2') {

                $emptyValueKeys[] = $key;
            }
        }
        $keyComparedStatus = array_diff($requestKeys, $keysInTheRequest);
        if(!empty($keyComparedStatus)) {

            $missedParameters = implode(",",$keyComparedStatus);
            $message = 'Failed';
            $returnData = [
                'error' => $missedParameters.' endpoint parameters are missing in the request'
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        if (!empty($emptyValueKeys)) {

            $emptyValueKeys = implode(",",$emptyValueKeys);
            $message = 'Failed';
            $returnData = [
                'error' => $emptyValueKeys.' endpoint parameter values are empty in the request'
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        $postPath = env('POST_NMMBG_URL',true);
        $response = $this->pharmaviteObj->postRequestData($postPath, $requestData);
        if (strtolower(trim($response)) != 'success') {

            $message = 'Failed';
            $returnData = [
                'error' => 'Error occured while posting the request to the API',
                'request' => $requestData
            ];
            Log::error($returnData);
            return $this->responseHelper->returnData($request->input('callback'), '600', $message, $returnData );
        }
        $message = 'Success';
        $returnData = [
            'message' => 'Successfully posted the given request in the API (Email: '.$receivedData->EMail.')'
        ];
        Log::info($returnData);
        return $this->responseHelper->returnData($request->input('callback'), '200', $message, $returnData );
    }
}
